<?php


class shamra_translation_widget extends WP_Widget {

    function __construct() {
        parent::__construct(
            'shamra_translation_widget',
            __('Shamra Translation Widget', 'shamra_translation_widget_domain'),
            array(
                'classname' => 'shamra_translation_widget_container',
                'description' => __( 'A Widget for displaying translation area provided by shamra.sy', 'shamra_translation_widget_domain' ),
                )
        );
    }

    private function filterField($string){
        $string = str_replace('"', "", $string);
        $string = str_replace("'", "", $string);
        return $string;
    }

    public function widget( $args, $instance ) {
        $title = apply_filters( 'widget_title', $instance['title'] );
        $token = isset( $instance[ 'token' ])? esc_attr($instance[ 'token' ]):'';
        $type = isset( $instance[ 'type' ])? esc_attr($instance[ 'type' ]):'small';
        $rows = isset( $instance[ 'rows' ])? esc_attr($instance[ 'rows' ]):'3';
        $fontSize = isset( $instance[ 'font_size' ])? esc_attr($instance[ 'font_size' ]):'13px';
        echo $args['before_widget'];
        if ( ! empty( $title ) )
            echo $args['before_title'] . $title . $args['after_title'];
        $dataToken = 'data-token="' . $token . '"';
        $dataTarget = 'data-target="shamra-translation-widget"';
        $dataType = 'data-type="' . $type . '"';
        $rowsOption = '"rows":"' . $rows . '"';
        $fontSizeOption = '"font_size":"' . $fontSize . '"';
        $dataOptions = 'data-options=\'{' . $rowsOption . ',' . $fontSizeOption .'}\'';
        $pluginScriptUrl =  plugins_url( '/assets/js/translation-api.js',__FILE__ );
        $src = 'src="' . $pluginScriptUrl . '"';
        echo "<script {$src} {$dataToken} {$dataTarget} {$dataType} {$dataOptions}></script>";
        echo "<div id='shamra-translation-widget'>جاري تحميل أداة الترجمة من شمرا...</div>";
        echo $args['after_widget'];
    }

// Widget Backend
    public function form( $instance ) {
        $title = isset( $instance[ 'title' ])? esc_attr($instance[ 'title' ]):__( 'New title', 'shamra_exchange_widget_domain' );
        $token = isset( $instance[ 'token' ])? esc_attr($instance[ 'token' ]):'';
        $type = isset( $instance[ 'type' ])? esc_attr($instance[ 'type' ]):'small';
        $rows = isset( $instance[ 'rows' ])? esc_attr($instance[ 'rows' ]):'3';
        $fontSize = isset( $instance[ 'font_size' ])? esc_attr($instance[ 'font_size' ]):'13px';
        $typeChecked = [
            'small' => false,
            'large' => false
        ];
        $typeChecked[$type] = true;
        ?>
        <p>
            <label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:' ); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
        </p>
        <p>
            <label for="<?php echo $this->get_field_id( 'token' ); ?>"><?php _e( 'Token:' ); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id( 'token' ); ?>" name="<?php echo $this->get_field_name( 'token' ); ?>" type="text" value="<?php echo esc_attr( $token ); ?>" />
        </p>
        <p>
            <label for="<?php echo $this->get_field_id( 'type' ); ?>"><?php _e( 'Type:' ); ?></label>
            <select class="widefat" id="<?php echo $this->get_field_id( 'type' ); ?>" name="<?php echo $this->get_field_name( 'type' ); ?>">
                <option value="small" <?php echo ($typeChecked['small'])?'selected':''; ?>><?php _e('Small widget'); ?></option>
                <option value="large" <?php echo ($typeChecked['large'])?'selected':''; ?>><?php _e('Large widget'); ?></option>
            </select>
        </p>
        <p>
            <label for="<?php echo $this->get_field_id( 'rows' ); ?>"><?php _e( 'Text area rows:' ); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id( 'rows' ); ?>" name="<?php echo $this->get_field_name( 'rows' ); ?>" type="number" value="<?php echo esc_attr( $rows ); ?>" />
        </p>
        <p>
            <label for="<?php echo $this->get_field_id( 'font_size' ); ?>"><?php _e( 'Font size:' ); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id( 'font_size' ); ?>" name="<?php echo $this->get_field_name( 'font_size' ); ?>" type="text" value="<?php echo esc_attr( $fontSize ); ?>" />
        </p>
	<p>
	You can check documentation at <a href="https://shamra.sy/developer/services/الترجمة">Shamra</a> official website.
	</p>
	<p style="color: gray;">
		Shamra Translation Widget 1.0.0
	</p>
        <?php
    }

    public function update( $new_instance, $old_instance ) {
        $instance = array();
        $instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
        $instance['token'] = ( ! empty( $new_instance['token'] ) ) ? strip_tags( $new_instance['token'] ) : '';
        $instance['type'] = ( ! empty( $new_instance['type'] ) ) ? strip_tags( $new_instance['type'] ) : 'small';
        $instance['rows'] = ( ! empty( $new_instance['rows'] ) ) ? strip_tags( $new_instance['rows'] ) : '3';
        $instance['font_size'] = ( ! empty( $new_instance['font_size'] ) ) ? strip_tags( $this->filterField($new_instance['font_size'] )) : '13px';
        return $instance;
    }
}
